@@ -18,6 +18,11 @@
         <source>Menu bar opacity</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Creating backups...</source>
@@ -412,6 +417,21 @@ déverrouillage</translation>
         <source>Backgrounds</source>
         <translation>Fond d&apos;écran</translation>
     </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Select image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Processing image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="backgrounds.cpp" line="0"/>
+        <source>Image saved!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>savepreset</name>
